@@ -1,6 +1,7 @@
 import io
 import json
 import logging
+import threading
 
 from flask import Flask, render_template, request, send_file
 from flask.views import View
@@ -12,6 +13,7 @@ from tileserver import utilities
 from tileserver.application.paths import get_path
 
 logger = logging.getLogger(__name__)
+REQUEST_TIMEOUT = 120
 
 
 class FloatConverter(BaseFloatConverter):
@@ -23,28 +25,39 @@ app.url_map.converters["float"] = FloatConverter
 cache = Cache(app, config={"CACHE_TYPE": "SimpleCache"})
 
 
+def make_cache_key(*args, **kwargs):
+    path = request.path
+    args = str(hash(frozenset(request.args.items())))
+    source = str(get_path())
+    ident = str(threading.get_ident())
+    return (path + args + ident + source).encode("utf-8")
+
+
 class BaseTileView(View):
     def get_tile_source(self, projection="EPSG:3857"):
         """Return the built tile source."""
         path = get_path()
         band = int(request.args.get("band", 0))
+        bmin = request.args.get("min", None)
+        bmax = request.args.get("max", None)
+        palette = request.args.get("palette", None)
+        nodata = request.args.get("nodata", None)
         style = None
+        # Handle when user sets min/max/etc. but forgot band. Defalt to 1
+        if not band and any(v is not None for v in [bmin, bmax, palette, nodata]):
+            band = 1
         if band:
             style = {"band": band}
-            bmin = request.args.get("min", None)
-            bmax = request.args.get("max", None)
             if bmin is not None:
                 style["min"] = bmin
             if bmax is not None:
                 style["max"] = bmax
-            palette = request.args.get("palette", None)
             if palette and utilities.is_valid_palette(palette):
                 style["palette"] = palette
             elif palette:
                 logger.error(
-                    f"Palette choice of {palette} is invalid. Check available palettes in the `palettable` package."
+                    f"Palette choice of {palette} is invalid. Check available palettes in the `palettable` package. Ignoring palette choice."
                 )
-            nodata = request.args.get("nodata", None)
             if nodata:
                 style["nodata"] = nodata
             style = json.dumps(style)
@@ -53,6 +66,7 @@ class BaseTileView(View):
 
 
 class MetadataView(BaseTileView):
+    @cache.cached(timeout=REQUEST_TIMEOUT, key_prefix=make_cache_key)
     def dispatch_request(self):
         tile_source = self.get_tile_source()
         return utilities.get_meta_data(tile_source)
@@ -69,7 +83,7 @@ class BoundsView(BaseTileView):
 
 
 class TilesView(BaseTileView):
-    @cache.memoize(timeout=120)
+    @cache.cached(timeout=REQUEST_TIMEOUT, key_prefix=make_cache_key)
     def dispatch_request(self, x: int, y: int, z: int):
         projection = request.args.get("projection", "EPSG:3857")
         tile_source = self.get_tile_source(projection=projection)
@@ -83,7 +97,7 @@ class TilesView(BaseTileView):
 
 
 class ThumbnailView(BaseTileView):
-    @cache.memoize(timeout=120)
+    @cache.cached(timeout=REQUEST_TIMEOUT, key_prefix=make_cache_key)
     def dispatch_request(self):
         tile_source = self.get_tile_source()
         thumb_data, mime_type = tile_source.getThumbnail(encoding="PNG")
