@@ -27,7 +27,7 @@ class Report(scooby.Report):
         ] + large_image_core
 
         # Optional packages.
-        optional = ["ipyleaflet", "large_image_source_gdal", "mapnik", "tifftools"]
+        optional = ["ipyleaflet", "large_image_source_mapnik", "tifftools"]
 
         scooby.Report.__init__(
             self,
